==> estateplat-common-1.2.4-20190201.073657-102-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXymx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2016/12/17
 * @description 不动产信用明细
 */
@Table(name = "bdc_xymx")
public class BdcXymx implements Serializable {

    //信用明细id
    @Id
    private String xymxid;
    //信用管理id
    private String xyglid;
    //内容
    private String nr;
    //创建时间
    private Date cjsj;
    //共享单位id
    private String gxdwid;
    //审核人
    private String shr;
    //审核时间
    private Date shsj;
    //是否生效
    private String sfsx;

    private String jcsxyy;

    private Date jcsxsj;

    private String jcsxr;

    private String bz;

    public String getXymxid() {
        return xymxid;
    }

    public void setXymxid(String xymxid) {
        this.xymxid = xymxid;
    }

    public String getXyglid() {
        return xyglid;
    }

    public void setXyglid(String xyglid) {
        this.xyglid = xyglid;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getNr() {
        return nr;
    }

    public void setNr(String nr) {
        this.nr = nr;
    }

    public String getGxdwid() {
        return gxdwid;
    }

    public void setGxdwid(String gxdwid) {
        this.gxdwid = gxdwid;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }

    public Date getShsj() {
        return shsj;
    }

    public void setShsj(Date shsj) {
        this.shsj = shsj;
    }

    public String getSfsx() {
        return sfsx;
    }

    public void setSfsx(String sfsx) {
        this.sfsx = sfsx;
    }

    public String getJcsxyy() {
        return jcsxyy;
    }

    public void setJcsxyy(String jcsxyy) {
        this.jcsxyy = jcsxyy;
    }

    public Date getJcsxsj() {
        return jcsxsj;
    }

    public void setJcsxsj(Date jcsxsj) {
        this.jcsxsj = jcsxsj;
    }

    public String getJcsxr() {
        return jcsxr;
    }

    public void setJcsxr(String jcsxr) {
        this.jcsxr = jcsxr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.4-20200929.055518-457-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXymx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2016/12/17
 * @description 不动产信用明细
 */
@Table(name = "bdc_xymx")
public class BdcXymx implements Serializable {

    //信用明细id
    @Id
    private String xymxid;
    //信用管理id
    private String xyglid;
    //内容
    private String nr;
    //创建时间
    private Date cjsj;
    //共享单位id
    private String gxdwid;
    //审核人
    private String shr;
    //审核时间
    private Date shsj;
    //是否生效 字典选项：0:否/1:是
    private String sfsx;
    //解除生效原因
    private String jcsxyy;
    //解除生效时间
    private Date jcsxsj;
    //解除生效人
    private String jcsxr;
    //备注
    private String bz;
    //查封文号
    private String cfwh;
    //查封机关
    private String cfjg;
    //发布人
    private String fbr;
    //发布时间
    private Date fbsj;
    //发布状态
    private String fbzt;
    //失效到期时间
    private Date sxdqsj;


    public String getXymxid() {
        return xymxid;
    }

    public void setXymxid(String xymxid) {
        this.xymxid = xymxid;
    }

    public String getXyglid() {
        return xyglid;
    }

    public void setXyglid(String xyglid) {
        this.xyglid = xyglid;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getNr() {
        return nr;
    }

    public void setNr(String nr) {
        this.nr = nr;
    }

    public String getGxdwid() {
        return gxdwid;
    }

    public void setGxdwid(String gxdwid) {
        this.gxdwid = gxdwid;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }

    public Date getShsj() {
        return shsj;
    }

    public void setShsj(Date shsj) {
        this.shsj = shsj;
    }

    public String getSfsx() {
        return sfsx;
    }

    public void setSfsx(String sfsx) {
        this.sfsx = sfsx;
    }

    public String getJcsxyy() {
        return jcsxyy;
    }

    public void setJcsxyy(String jcsxyy) {
        this.jcsxyy = jcsxyy;
    }

    public Date getJcsxsj() {
        return jcsxsj;
    }

    public void setJcsxsj(Date jcsxsj) {
        this.jcsxsj = jcsxsj;
    }

    public String getJcsxr() {
        return jcsxr;
    }

    public void setJcsxr(String jcsxr) {
        this.jcsxr = jcsxr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    public String getFbr() {
        return fbr;
    }

    public void setFbr(String fbr) {
        this.fbr = fbr;
    }

    public Date getFbsj() {
        return fbsj;
    }

    public void setFbsj(Date fbsj) {
        this.fbsj = fbsj;
    }

    public String getFbzt() {
        return fbzt;
    }

    public void setFbzt(String fbzt) {
        this.fbzt = fbzt;
    }

    public Date getSxdqsj() {
        return sxdqsj;
    }

    public void setSxdqsj(Date sxdqsj) {
        this.sxdqsj = sxdqsj;
    }
}
